@@ -15,7 +15,7 @@ impl MinFlt {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("MinorFaults"));
         let unit = String::new();
-        MinFlt {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
@@ -35,7 +35,7 @@ impl Column for MinFlt {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
 
 #[cfg(target_os = "macos")]
@@ -49,7 +49,7 @@ impl Column for MinFlt {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
 
 #[cfg(target_os = "freebsd")]
@@ -62,5 +62,5 @@ impl Column for MinFlt {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(u64);
+    column_default!(u64, true);
 }
