@@ -11,12 +11,11 @@ pub struct Slot {
     width: usize,
 }
 
-#[cfg_attr(tarpaulin, skip)]
 impl Slot {
     pub fn new() -> Self {
         let header = String::new();
         let unit = String::new();
-        Slot {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
@@ -26,7 +25,6 @@ impl Slot {
     }
 }
 
-#[cfg_attr(tarpaulin, skip)]
 impl Column for Slot {
     fn add(&mut self, proc: &ProcessInfo) {
         let raw_content = String::new();
@@ -36,5 +34,5 @@ impl Column for Slot {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
